searchNodes=[{"doc":"Job pools for Elixir OTP applications, written in Elixir. Usage You can add job pools directly to the top level of your own application's supervision tree: defmodule MyApp.Application do use Application def start ( _type , _args ) do children = [ { OddJob , :email } , { OddJob , :task } ] opts = [ strategy : :one_for_one , name : MyApp.Supervisor ] Supervisor . start_link ( children , opts ) end end The tuple {OddJob, :email} will return a child spec for a supervisor that will start and supervise the :email pool. The second element of the tuple can be any atom that you want to use as a unique name for the pool. You can also configure OddJob to supervise your pools for you in a separate supervision tree. In your config.exs : config :odd_job , supervise : [ :email , :task ] You can also configure a custom pool size that will apply to all pools: config :odd_job , pool_size : 10 # the default value is 5 Now you can call on your pools to perform concurrent fire and forget jobs: OddJob . perform ( :email , fn -&gt; send_confirmation_email ( ) end ) OddJob . perform ( :task , fn -&gt; update_external_application ( ) end )","ref":"OddJob.html","title":"OddJob","type":"module"},{"doc":"Performs an async job that can be awaited on for the result. Functions like Task.async/1 and Task.await/2 . Examples iex&gt; job = OddJob . async_perform ( :work , fn -&gt; :math . exp ( 100 ) end ) iex&gt; OddJob . await ( job ) 2.6881171418161356e43","ref":"OddJob.html#async_perform/2","title":"OddJob.async_perform/2","type":"function"},{"doc":"Awaits on an async job and returns the results. Examples iex&gt; OddJob . async_perform ( :work , fn -&gt; :math . log ( 2.6881171418161356e43 ) end ) ...&gt; |&gt; OddJob . await ( ) 100.0","ref":"OddJob.html#await/2","title":"OddJob.await/2","type":"function"},{"doc":"Awaits replies form multiple async jobs and returns them in a list. This function receives a list of jobs and waits for their replies in the given time interval. It returns a list of the results, in the same order as the jobs supplied in the jobs input argument. If any of the job worker processes dies, the caller process will exit with the same reason as that worker. A timeout, in milliseconds or :infinity , can be given with a default value of 5000 . If the timeout is exceeded, then the caller process will exit. Any worker processes that are linked to the caller process (which is the case when a job is started with async_perform/2 ) will also exit. This function assumes the jobs' monitors are still active or the monitor's :DOWN message is in the message queue. If any jobs have been demonitored, or the message already received, this function will wait for the duration of the timeout. Examples iex&gt; job1 = OddJob . async_perform ( :work , fn -&gt; 2 * * 2 end ) iex&gt; job2 = OddJob . async_perform ( :work , fn -&gt; 3 * * 2 end ) iex&gt; [ job1 , job2 ] |&gt; OddJob . await_many ( ) [ 4 , 9 ]","ref":"OddJob.html#await_many/2","title":"OddJob.await_many/2","type":"function"},{"doc":"Performs a fire and forget job. Examples iex&gt; parent = self ( ) iex&gt; :ok = OddJob . perform ( :work , fn -&gt; send ( parent , :hello ) end ) iex&gt; receive do ...&gt; msg -&gt; msg ...&gt; end :hello","ref":"OddJob.html#perform/2","title":"OddJob.perform/2","type":"function"},{"doc":"Adds a job to the queue of the job pool after the given timer has elapsed. timer is an integer that indicates the number of milliseconds that should elapse before the job enters the queue. The timed message is executed under a separate supervised process, so if the caller crashes the job will still be performed. A timer reference is returned, which can be read with Process.read_timer/1 or canceled with Process.cancel_timer/1 . Examples timer_ref = OddJob . perform_after ( 5000 , :work , fn -&gt; deferred_job ( ) end ) Process . read_timer ( timer_ref ) #=&gt; 2836 # time remaining before job enters the queue Process . cancel_timer ( timer_ref ) #=&gt; 1175 # job has been cancelled timer_ref = OddJob . perform_after ( 5000 , :work , fn -&gt; deferred_job ( ) end ) Process . sleep ( 6000 ) Process . cancel_timer ( timer_ref ) #=&gt; false # too much time has passed to cancel the job","ref":"OddJob.html#perform_after/3","title":"OddJob.perform_after/3","type":"function"},{"doc":"Adds a job to the queue of the job pool at the given time . time can be a Time or a DateTime struct. If a Time struct is received, then the job will be done the next time the clock strikes the given time. The timed message is executed under a separate supervised process, so if the caller crashes the job will still be performed. A timer reference is returned, which can be read with Process.read_timer/1 or canceled with Process.cancel_timer/1 . Examples time = Time . utc_now ( ) |&gt; Time . add ( 600 , :second ) OddJob . perform_at ( time , :work , fn -&gt; scheduled_job ( ) end )","ref":"OddJob.html#perform_at/3","title":"OddJob.perform_at/3","type":"function"},{"doc":"Returns the pid and state of the job pool 's queue. Examples iex&gt; { pid , % OddJob.Queue { id : id } } = OddJob . queue ( :work ) iex&gt; is_pid ( pid ) true iex&gt; id :odd_job_work_queue","ref":"OddJob.html#queue/1","title":"OddJob.queue/1","type":"function"},{"doc":"Returns the ID of the job pool 's queue. Examples iex&gt; OddJob . queue_id ( :work ) :odd_job_work_queue","ref":"OddJob.html#queue_id/1","title":"OddJob.queue_id/1","type":"function"},{"doc":"Returns the pid of the job pool 's supervisor. There is no guarantee that the process will still be alive after the results are returned, as it could exit or be killed or restarted at any time. Use supervisor_id/1 to obtain the persistent ID of the supervisor. Examples OddJob . supervisor ( :work ) #=&gt; #PID&lt;0.239.0&gt;","ref":"OddJob.html#supervisor/1","title":"OddJob.supervisor/1","type":"function"},{"doc":"Returns the ID of the job pool 's supervisor. Examples iex&gt; OddJob . supervisor_id ( :work ) :odd_job_work_sup","ref":"OddJob.html#supervisor_id/1","title":"OddJob.supervisor_id/1","type":"function"},{"doc":"Returns a list of pid s for the specified worker pool. There is no guarantee that the processes will still be alive after the results are returned, as they could exit or be killed at any time. Examples OddJob . workers ( :work ) #=&gt; [#PID&lt;0.105.0&gt;, #PID&lt;0.106.0&gt;, #PID&lt;0.107.0&gt;, #PID&lt;0.108.0&gt;, #PID&lt;0.109.0&gt;]","ref":"OddJob.html#workers/1","title":"OddJob.workers/1","type":"function"},{"doc":"","ref":"OddJob.html#t:child_spec/0","title":"OddJob.child_spec/0","type":"type"},{"doc":"","ref":"OddJob.html#t:job/0","title":"OddJob.job/0","type":"type"},{"doc":"","ref":"OddJob.html#t:queue/0","title":"OddJob.queue/0","type":"type"},{"doc":"The OddJob.Job struct holds all of the useful information about a job.","ref":"OddJob.Job.html","title":"OddJob.Job","type":"module"},{"doc":"The OddJob.Job struct is the datatype that is passed between processes charged with performing the job. It holds all of the data that is necessary to link, monitor, perform work, and return results to the caller. The job struct is only returned to the caller when using the async/await pattern. When the caller receives the struct after calling OddJob.async_perform/2 the :results field is always nil , even though the work could conceivably already be done. This is because the results are not waited on at the time the struct is created. The results are only known when passing the job to OddJob.await/2 or matching on the {ref, results} message. :function is the anonymous function that will be performed by the worker :results is the term that is returned by function . This is only used internally by the processes performing the work. :async is an boolean identifying if the job's results can be awaited on :ref is the unique monitor reference of the job :owner is the pid of the calling process, i.e. self() :proxy is the pid of the proxy server that creates the job and routes the results. The owner links and monitors the proxy , while the proxy links and monitors the worker. Exit messages and failures cascade up to the owner . The worker sends results back to the proxy , which then sends them to the owner before exiting with reason :normal .","ref":"OddJob.Job.html#t:t/0","title":"OddJob.Job.t/0","type":"type"},{"doc":"The job queue that manages the assignments given to the pool workers.","ref":"OddJob.Queue.html","title":"OddJob.Queue","type":"module"},{"doc":"","ref":"OddJob.Queue.html#t:job/0","title":"OddJob.Queue.job/0","type":"type"},{"doc":"The OddJob.Queue struct holds the state of the job queue. :id is an atom representing the registered name of the queue process :supervisor is an atom representing the registered name of the queue's supervisor process :workers is a list of the active worker pid s, whether they are busy working or not :assigned is a list of the worker pid s that are currently assigned to a job :jobs is a list of OddJob.Job structs representing the jobs that are queued to be performed when workers are available","ref":"OddJob.Queue.html#t:t/0","title":"OddJob.Queue.t/0","type":"type"}]